==> haskell-string-conversions-0.4.0.1-237-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-Ksp1CPdJZPnJP2XXT3pP4q
key:                  string-conversions-0.4.0.1-Ksp1CPdJZPnJP2XXT3pP4q
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  ba5062ecde41aad7e9a497eb97d87dc3
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/string-conversions-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-Ksp1CPdJZPnJP2XXT3pP4q
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    utf8-string-1.0.2-JoSH3X8qo5Q4jcipebjMdu

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-conversions-0.4.0.1-245-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 string-conversions
version:              0.4.0.1
visibility:           public
id:                   string-conversions-0.4.0.1-9W5gAJGgYFw31wciCYuIRT
key:                  string-conversions-0.4.0.1-9W5gAJGgYFw31wciCYuIRT
license:              BSD-3-Clause
maintainer:           soenkehahn@gmail.com
author:               Sönke Hahn
homepage:             https://github.com/soenkehahn/string-conversions#readme
synopsis:             Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.

category:             Data
abi:                  7cd584c20fd435c5c1c054ba3d77aa27
exposed:              True
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic

import-dirs:          /usr/lib/ghc-9.4.8/site-local/string-conversions-0.4.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/string-conversions-0.4.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-string-conversions
hs-libraries:         HSstring-conversions-0.4.0.1-9W5gAJGgYFw31wciCYuIRT
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    utf8-string-1.0.2-3k9iW3aOua82FWJzfAeOkO

haddock-interfaces:
    /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock

haddock-html:         /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
